//----------------
// Player class
//----------------
var accel = 1.6;
var maxVel = 20;
var jumpPower = 8.5;
var gravity = 0.4;

var playerSS = new SpriteSheet({
	images:["./img/player.png"],
	frames:{width:20, height:40, count: 5},
	animations:{
		walk:[0, 2, true, 0.2],
		jump:[3, 3, false, 0.2],
		stand:[0, 0, false, 0.2],
		warp:[4, 4, false, 0.2]
	}
});

(function() {
	
	//--------------
	// constructor
	//--------------
	var Player = function() {
		this.initialize(playerSS, "stand");
		this.width = 20;
		this.height = 40;
	};
	
	// inherit
	var p = Player.prototype = new Sprite();
	
	// property
	p.width = 0;
	p.height = 0;
	p.ground = false;
	p.velocityX = 0;
	p.velocityY = 0;
	p.jumped = false;
	p.controllable = false;
	p.dieCount = 0;
	
	//--------
	// start
	//--------
	p.start = function(){
		this.x = 40;
		this.y = 20;
		this.velocityX = 0;
		this.velocityY = 0;
		this.controllable = false;
	}
	
	//--------
	// move
	//--------
	p.move = function(){
		
		// gravity
		this.velocityY += gravity;
		if(this.velocityY > maxVel){
			this.velocityY = maxVel * this.scaleX;
		}
		if(this.velocityY > gravity && this.ground){
			this.ground = false;
		}
		
		// move
		this.x += this.velocityX * this.scaleX;
		this.y += this.velocityY * this.scaleX;
		
		// die
		if(this.y + this.height < 0 || 600 < this.y){
			this.die();
		}
		
		// reduce velocity
		this.velocityX *= 0.6;
		if(Math.abs(this.velocityX * this.scaleX) < 0.05){
			this.velocityX = 0;
		}
		
		// animation
		if(this.ground == false){
			this.gotoAndStop("jump");
		}else if(this.velocityX != 0){
			if(this.currentAnimation != "walk"){
				this.gotoAndPlay("walk");
			}
		}else{
			this.gotoAndStop("stand");
		}
	}
	
	//--------------
	// left
	//--------------
	p.left = function(){
		if(this.controllable){
			this.velocityX -= accel;
			if(this.velocityX < -maxVel){
				this.velocityX = -maxVel;
			}
		}
	}
	
	//--------------
	// right
	//--------------
	p.right = function(){
		if(this.controllable){
			this.velocityX += accel;
			if(this.velocityX > maxVel){
				this.velocityX = maxVel;
			}
		}
	}
	
	//--------------
	// jump
	//--------------
	p.jump = function(){
		if(this.controllable){
			if(this.ground && this.jumped == false){
				soundJump.play();
				this.velocityY = - jumpPower;
				this.y += 1 * this.scaleX;
				this.ground = false;
				this.jumped = true;
			}
		}
	}
	
	//--------------
	// die
	//--------------
	p.die = function(){
		soundDie.play();
		this.dieCount ++;
		if(this.dieCount % 5 == 0 && currentStage < 11){
			centerText.text = "R key to retry";
			timeoutList.push(setTimeout(function(){centerText.text = ""}, 4000));
		}
		
		for(var i=0; i<12; i++){
			gameContainer.addChild(new Emitter(0, this.x + (this.width/2), this.y + (this.height/2), Math.random() * 6 - 3, Math.random() * 6 - 3, this.scaleX));
		}
		this.start();
	}
	
	//--------------
	// set scale
	//--------------
	p.setScale = function(inScale){
		this.scaleX = inScale;
		this.scaleY = inScale;
		this.width = this.getBounds().width * inScale;
		this.height = this.getBounds().height * inScale;
	}
	
	// regist
	createjs.Player = Player;
}());
